@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Dist::Zilla::App::Command::listdeps;
+package Dist::Zilla::App::Command::listdeps 6.013; # TRIAL
 # ABSTRACT: print your distribution's prerequisites
-$Dist::Zilla::App::Command::listdeps::VERSION = '6.004'; # TRIAL
+
 use Dist::Zilla::App -command;
 
 #pod =head1 SYNOPSIS
@@ -26,6 +26,24 @@ use Dist::Zilla::App -command;
 #pod
 #pod List only dependencies which are unsatisfied.
 #pod
+#pod =head2 --requires / --no-requires
+#pod
+#pod Add required dependencies to the list (or don't).
+#pod
+#pod Default: on.
+#pod
+#pod =head2 --recommends / --no-recommends
+#pod
+#pod Add recommended dependencies to the list (or don't).
+#pod
+#pod Default: on.
+#pod
+#pod =head2 --suggests / --no-suggests
+#pod
+#pod Add suggested dependencies to the list (or don't).
+#pod
+#pod Default: off.
+#pod
 #pod =head2 --versions
 #pod
 #pod Also display the required versions of listed modules.
@@ -48,13 +66,14 @@ use Dist::Zilla::App -command;
 #pod
 #pod =cut
 
-use Try::Tiny;
-
 sub abstract { "print your distribution's prerequisites" }
 
 sub opt_spec {
   [ 'develop|author', 'include author/develop dependencies' ],
   [ 'missing', 'list only the missing dependencies' ],
+  [ 'requires!', 'list the required dependencies', { default => 1 } ],
+  [ 'recommends!', 'list the recommended dependencies', { default => 1 } ],
+  [ 'suggests!', 'list the suggested dependencies', {default => 0 } ],
   [ 'versions', 'include required version numbers in listing' ],
   [ 'cpanm-versions', 'format versions for consumption by cpanm' ],
   [ 'json', 'list dependencies by phase, in JSON format' ],
@@ -95,35 +114,35 @@ sub filter_core {
 }
 
 sub extract_dependencies {
-  my ($self, $zilla, $phases, $missing, $omit_core) = @_;
+  my ($self, $zilla, $phases, $opt) = @_;
 
   my $prereqs = $self->prereqs($zilla);
-  $prereqs = filter_core($prereqs, $omit_core) if $omit_core;
+  $prereqs = filter_core($prereqs, $opt->omit_core) if $opt->omit_core;
 
   require CPAN::Meta::Requirements;
   my $req = CPAN::Meta::Requirements->new;
 
   for my $phase (@$phases) {
-    $req->add_requirements( $prereqs->requirements_for($phase, 'requires') );
-    $req->add_requirements( $prereqs->requirements_for($phase, 'recommends') );
+    $req->add_requirements( $prereqs->requirements_for($phase, 'requires') )   if $opt->requires;
+    $req->add_requirements( $prereqs->requirements_for($phase, 'recommends') ) if $opt->recommends;
+    $req->add_requirements( $prereqs->requirements_for($phase, 'suggests') )   if $opt->suggests;
   }
 
-  require Class::Load;
-
   my @required = grep { $_ ne 'perl' } $req->required_modules;
-  if ($missing) {
-    my $is_required = sub {
-      my $mod = shift;
-      # it is required if it's not already installed
-      return 1 unless Class::Load::try_load_class($mod);
-
-      # guard against libs with -1 in $VERSION and other insanity
-      my $version;
-      return unless try { $version = $mod->VERSION; 1; };
-
-      return !$req->accepts_module($mod => $version);
-    };
-    @required = grep { $is_required->($_) } @required;
+  if ($opt->missing) {
+    require Module::Runtime;
+    @required =
+      grep {
+        # Keep modules that can't be loaded or that don't have a $VERSION
+        # matching our requirements
+        ! eval {
+          my $m = $_;
+          # Will die if module is not installed
+          Module::Runtime::require_module($m);
+          # Returns true if $VERSION matches, so we will exclude the module
+          $req->accepts_module($m => $m->VERSION)
+        }
+      } @required;
   }
 
   my $versions = $req->as_string_hash;
@@ -149,17 +168,15 @@ sub execute {
     return 1;
   }
 
-  my %modules = $self->extract_dependencies($self->zilla, \@phases, $opt->missing, $opt->omit_core);
+  my %modules = $self->extract_dependencies($self->zilla, \@phases, $opt);
 
-  if ($opt->versions or $opt->cpanm_versions) {
-    my @names = sort { lc $a cmp lc $b } keys %modules;
-    if ($opt->cpanm_versions) {
-      print qq{$_~"$modules{$_}"\n} for @names;
-    } else {
+  my @names = sort { lc $a cmp lc $b } keys %modules;
+  if ($opt->versions) {
       print "$_ = $modules{$_}\n" for @names;
-    }
+  } elsif ($opt->cpanm_versions) {
+      print qq{$_~"$modules{$_}"\n} for @names;
   } else {
-      print "$_\n" for sort { lc $a cmp lc $b } keys(%modules);
+      print "$_\n" for @names;
   }
 }
 
@@ -177,7 +194,7 @@ Dist::Zilla::App::Command::listdeps - print your distribution's prerequisites
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 SYNOPSIS
 
@@ -200,6 +217,24 @@ Include author dependencies (those listed under C<develop_requires>).
 
 List only dependencies which are unsatisfied.
 
+=head2 --requires / --no-requires
+
+Add required dependencies to the list (or don't).
+
+Default: on.
+
+=head2 --recommends / --no-recommends
+
+Add recommended dependencies to the list (or don't).
+
+Default: on.
+
+=head2 --suggests / --no-suggests
+
+Add suggested dependencies to the list (or don't).
+
+Default: off.
+
 =head2 --versions
 
 Also display the required versions of listed modules.
@@ -222,11 +257,11 @@ API.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
