@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Dist::Zilla::App::Command::new;
+package Dist::Zilla::App::Command::new 6.013; # TRIAL
 # ABSTRACT: mint a new dist
-$Dist::Zilla::App::Command::new::VERSION = '6.004'; # TRIAL
+
 use Dist::Zilla::App -command;
 
 #pod =head1 SYNOPSIS
@@ -41,7 +41,7 @@ use Dist::Zilla::App -command;
 
 sub abstract { 'mint a new dist' }
 
-sub usage_desc { '%c %o <ModuleName>' }
+sub usage_desc { '%c new %o <ModuleName>' }
 
 sub opt_spec {
   [ 'profile|p=s',  'name of the profile to use',
@@ -109,7 +109,7 @@ Dist::Zilla::App::Command::new - mint a new dist
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 SYNOPSIS
 
@@ -145,11 +145,11 @@ in the F<~/.dzil/config.ini> file, for example:
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
