@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Dist::Zilla::App::Command::smoke;
+package Dist::Zilla::App::Command::smoke 6.013; # TRIAL
 # ABSTRACT: smoke your dist
-$Dist::Zilla::App::Command::smoke::VERSION = '6.004'; # TRIAL
+
 use Dist::Zilla::App -command;
 
 #pod =head1 SYNOPSIS
@@ -78,7 +78,7 @@ Dist::Zilla::App::Command::smoke - smoke your dist
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 SYNOPSIS
 
@@ -119,11 +119,11 @@ This will run the test suite with AUTHOR_TESTING=1
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
