@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Dist::Zilla::App::Command::test;
+package Dist::Zilla::App::Command::test 6.013; # TRIAL
 # ABSTRACT: test your dist
-$Dist::Zilla::App::Command::test::VERSION = '6.004'; # TRIAL
+
 use Dist::Zilla::App -command;
 
 #pod =head1 SYNOPSIS
@@ -100,7 +100,7 @@ Dist::Zilla::App::Command::test - test your dist
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 SYNOPSIS
 
@@ -147,11 +147,11 @@ Equivalent to --release --automated --extended --author
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
