@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Dist::Zilla::App::Command::version;
+package Dist::Zilla::App::Command::version 6.013; # TRIAL
 # ABSTRACT: display dzil's version
-$Dist::Zilla::App::Command::version::VERSION = '6.004'; # TRIAL
+
 use Dist::Zilla::App -command;
 use App::Cmd::Command::version;
 BEGIN {
@@ -40,7 +40,7 @@ Dist::Zilla::App::Command::version - display dzil's version
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 SYNOPSIS
 
@@ -50,11 +50,11 @@ Print dzil version
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
