@@ -1,6 +1,6 @@
-package Dist::Zilla::Dist::Builder;
+package Dist::Zilla::Dist::Builder 6.013; # TRIAL
 # ABSTRACT: dist zilla subclass for building dists
-$Dist::Zilla::Dist::Builder::VERSION = '6.004'; # TRIAL
+
 use Moose 0.92; # role composition fixes
 extends 'Dist::Zilla';
 
@@ -11,6 +11,7 @@ use File::pushd ();
 use Dist::Zilla::Path; # because more Path::* is better, eh?
 use Try::Tiny;
 use List::Util 1.45 'uniq';
+use Module::Runtime 'require_module';
 
 use namespace::autoclean;
 
@@ -209,7 +210,7 @@ sub _setup_default_plugins {
       plugin_name => ':NoFiles',
       zilla       => $self,
       style       => 'list',
-      code        => sub { return },
+      code        => sub { [] },
     });
 
     push @{ $self->plugins }, $plugin;
@@ -258,7 +259,7 @@ sub _load_config {
   my $config_class =
     $arg->{config_class} ||= 'Dist::Zilla::MVP::Reader::Finder';
 
-  Class::Load::load_class($config_class);
+  require_module($config_class);
 
   $arg->{chrome}->logger->log_debug(
     { prefix => '[DZ] ' },
@@ -479,8 +480,8 @@ sub build_archive {
 
   $_->before_archive for @{ $self->plugins_with(-BeforeArchive) };
 
-  my $method = Class::Load::load_optional_class('Archive::Tar::Wrapper',
-                                                { -version => 0.15 })
+  my $method = eval { +require Archive::Tar::Wrapper;
+                      Archive::Tar::Wrapper->VERSION('0.15'); 1 }
              ? '_build_archive_with_wrapper'
              : '_build_archive';
 
@@ -874,7 +875,7 @@ Dist::Zilla::Dist::Builder - dist zilla subclass for building dists
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 ATTRIBUTES
 
@@ -1024,11 +1025,11 @@ non-zero, the directory will be left in place.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
