@@ -1,6 +1,6 @@
-package Dist::Zilla::MVP::Reader::Perl;
+package Dist::Zilla::MVP::Reader::Perl 6.013; # TRIAL
 # ABSTRACT: the reader for dist.pl files
-$Dist::Zilla::MVP::Reader::Perl::VERSION = '6.004'; # TRIAL
+
 use Moose;
 extends 'Config::MVP::Reader';
 with qw(Config::MVP::Reader::Findable::ByExtension);
@@ -18,7 +18,7 @@ sub default_extension { 'pl' }
 sub read_into_assembler {
   my ($self, $location, $asm) = @_;
 
-  my @input = do $location;
+  my @input = do File::Spec->rel2abs($location);
   while (@input and ! ref $input[0]) {
     my ($key, $value) = (shift(@input), shift(@input));
     $asm->add_value($key => $value);
@@ -63,7 +63,7 @@ Dist::Zilla::MVP::Reader::Perl - the reader for dist.pl files
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 DESCRIPTION
 
@@ -71,11 +71,11 @@ Dist::Zilla::Config reads in the F<dist.pl> file for a distribution.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
