@@ -1,6 +1,6 @@
-package Dist::Zilla::MintingProfile::Default;
+package Dist::Zilla::MintingProfile::Default 6.013; # TRIAL
 # ABSTRACT: Default minting profile provider
-$Dist::Zilla::MintingProfile::Default::VERSION = '6.004'; # TRIAL
+
 use Moose;
 with 'Dist::Zilla::Role::MintingProfile::ShareDir';
 
@@ -48,7 +48,7 @@ Dist::Zilla::MintingProfile::Default - Default minting profile provider
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 DESCRIPTION
 
@@ -59,11 +59,11 @@ if not found it looks among the default profiles shipped with Dist::Zilla.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
