@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::AutoPrereqs;
+package Dist::Zilla::Plugin::AutoPrereqs 6.013; # TRIAL
 # ABSTRACT: automatically extract prereqs from your modules
-$Dist::Zilla::Plugin::AutoPrereqs::VERSION = '6.004'; # TRIAL
+
 use Moose;
 with(
   'Dist::Zilla::Role::PrereqScanner',
@@ -166,7 +166,7 @@ Dist::Zilla::Plugin::AutoPrereqs - automatically extract prereqs from your modul
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 SYNOPSIS
 
@@ -253,11 +253,11 @@ This plugin was originally contributed by Jerome Quelin.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
