@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::CPANFile;
+package Dist::Zilla::Plugin::CPANFile 6.013; # TRIAL
 # ABSTRACT: produce a cpanfile prereqs file
-$Dist::Zilla::Plugin::CPANFile::VERSION = '6.004'; # TRIAL
+
 use Moose;
 with 'Dist::Zilla::Role::FileGatherer';
 
@@ -8,6 +8,11 @@ use namespace::autoclean;
 
 use Dist::Zilla::File::FromCode;
 
+#pod =head1 SYNOPSIS
+#pod
+#pod     # dist.ini
+#pod     [CPANFile]
+#pod
 #pod =head1 DESCRIPTION
 #pod
 #pod This plugin will add a F<cpanfile> file to the distribution.
@@ -17,6 +22,17 @@ use Dist::Zilla::File::FromCode;
 #pod If given, parameter allows you to specify an alternate name for the generated
 #pod file.  It defaults, of course, to F<cpanfile>.
 #pod
+#pod     # dist.ini
+#pod     [CPANFile]
+#pod     filename = dzil-generated-cpanfile
+#pod
+#pod =head1 SEE ALSO
+#pod
+#pod =for :list
+#pod * L<Module::CPANfile>
+#pod * L<Carton>
+#pod * L<cpanm>
+#pod
 #pod =cut
 
 has filename => (
@@ -88,7 +104,12 @@ Dist::Zilla::Plugin::CPANFile - produce a cpanfile prereqs file
 
 =head1 VERSION
 
-version 6.004
+version 6.013
+
+=head1 SYNOPSIS
+
+    # dist.ini
+    [CPANFile]
 
 =head1 DESCRIPTION
 
@@ -101,13 +122,35 @@ This plugin will add a F<cpanfile> file to the distribution.
 If given, parameter allows you to specify an alternate name for the generated
 file.  It defaults, of course, to F<cpanfile>.
 
+    # dist.ini
+    [CPANFile]
+    filename = dzil-generated-cpanfile
+
+=head1 SEE ALSO
+
+=over 4
+
+=item *
+
+L<Module::CPANfile>
+
+=item *
+
+L<Carton>
+
+=item *
+
+L<cpanm>
+
+=back
+
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
