@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::ExecDir;
+package Dist::Zilla::Plugin::ExecDir 6.013; # TRIAL
 # ABSTRACT: install a directory's contents as executables
-$Dist::Zilla::Plugin::ExecDir::VERSION = '6.004'; # TRIAL
+
 use Moose;
 
 use namespace::autoclean;
@@ -22,15 +22,6 @@ has dir => (
   default => 'bin',
 );
 
-sub find_files {
-  my ($self) = @_;
-
-  my $dir = $self->dir;
-  my $files = [
-    grep { index($_->name, "$dir/") == 0 } @{ $self->zilla->files }
-  ];
-}
-
 with 'Dist::Zilla::Role::ExecFiles';
 __PACKAGE__->meta->make_immutable;
 1;
@@ -47,7 +38,7 @@ Dist::Zilla::Plugin::ExecDir - install a directory's contents as executables
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 SYNOPSIS
 
@@ -60,11 +51,11 @@ If no C<dir> is provided, the default is F<bin>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
