@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::ExtraTests;
+package Dist::Zilla::Plugin::ExtraTests 6.013; # TRIAL
 # ABSTRACT: rewrite ./xt tests to ./t tests with skips
-$Dist::Zilla::Plugin::ExtraTests::VERSION = '6.004'; # TRIAL
+
 use Moose;
 with 'Dist::Zilla::Role::FileMunger';
 
@@ -58,8 +58,8 @@ sub _rewrite {
   splice @lines, $after, 0, qq|
 BEGIN {
   unless (\$ENV{$env}) {
-    require Test::More;
-    Test::More::plan(skip_all => 'these tests are for $msg');
+    print qq{1..0 # SKIP these tests are for $msg\\n};
+    exit
   }
 }
 |;
@@ -82,7 +82,7 @@ Dist::Zilla::Plugin::ExtraTests - rewrite ./xt tests to ./t tests with skips
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 DESCRIPTION
 
@@ -98,11 +98,11 @@ not set.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
