@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::FakeRelease;
+package Dist::Zilla::Plugin::FakeRelease 6.013; # TRIAL
 # ABSTRACT: fake plugin to test release
-$Dist::Zilla::Plugin::FakeRelease::VERSION = '6.004'; # TRIAL
+
 use Moose;
 with 'Dist::Zilla::Role::Releaser';
 
@@ -73,7 +73,7 @@ Dist::Zilla::Plugin::FakeRelease - fake plugin to test release
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 SYNOPSIS
 
@@ -106,11 +106,11 @@ L<UploadToCPAN|Dist::Zilla::Plugin::UploadToCPAN>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
