@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::FileFinder::ByName;
+package Dist::Zilla::Plugin::FileFinder::ByName 6.013; # TRIAL
 # ABSTRACT: FileFinder matching on pathnames
-$Dist::Zilla::Plugin::FileFinder::ByName::VERSION = '6.004'; # TRIAL
+
 use Moose;
 with 'Dist::Zilla::Role::FileFinder';
 
@@ -95,16 +95,12 @@ sub mvp_multivalue_args { qw(dirs files matches skips) }
 
 sub _join_re {
   my $list = shift;
-
-  return undef if @$list == 0;
-
-  my $re = qr/(?:$list->[0])/;
-
-  for my $i (1 .. $#$list) {
-    $re = qr/$re|(?:$list->[$i])/;
-  }
-
-  $re;
+  return undef unless @$list;
+  # Special case to avoid stringify+compile
+  return $list->[0] if @$list == 1;
+  # Wrap each element to ensure that alternations are isolated
+  my $re = join('|', map { "(?:$_)" } @$list);
+  qr/$re/
 }
 
 sub find_files {
@@ -180,7 +176,7 @@ Dist::Zilla::Plugin::FileFinder::ByName - FileFinder matching on pathnames
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 SYNOPSIS
 
@@ -251,11 +247,11 @@ find_files
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
