@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::InlineFiles;
+package Dist::Zilla::Plugin::InlineFiles 6.013; # TRIAL
 # ABSTRACT: files in a data section
-$Dist::Zilla::Plugin::InlineFiles::VERSION = '6.004'; # TRIAL
+
 use Moose;
 with 'Dist::Zilla::Role::FileGatherer';
 
@@ -62,7 +62,7 @@ Dist::Zilla::Plugin::InlineFiles - files in a data section
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 DESCRIPTION
 
@@ -79,11 +79,11 @@ L<PodSyntaxTests|Dist::Zilla::Plugin::PodSyntaxTests>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
