@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::License;
+package Dist::Zilla::Plugin::License 6.013; # TRIAL
 # ABSTRACT: output a LICENSE file
-$Dist::Zilla::Plugin::License::VERSION = '6.004'; # TRIAL
+
 use Moose;
 with 'Dist::Zilla::Role::FileGatherer';
 
@@ -77,7 +77,7 @@ Dist::Zilla::Plugin::License - output a LICENSE file
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 DESCRIPTION
 
@@ -115,11 +115,11 @@ L<Software::License::Artistic_2_0>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
