@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::MakeMaker::Runner;
+package Dist::Zilla::Plugin::MakeMaker::Runner 6.013; # TRIAL
 # ABSTRACT: Test and build dists with a Makefile.PL
-$Dist::Zilla::Plugin::MakeMaker::Runner::VERSION = '6.004'; # TRIAL
+
 use Moose;
 with(
   'Dist::Zilla::Role::BuildRunner',
@@ -73,15 +73,15 @@ Dist::Zilla::Plugin::MakeMaker::Runner - Test and build dists with a Makefile.PL
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
