@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::MetaNoIndex;
+package Dist::Zilla::Plugin::MetaNoIndex 6.013; # TRIAL
 # ABSTRACT: Stop CPAN from indexing stuff
-$Dist::Zilla::Plugin::MetaNoIndex::VERSION = '6.004'; # TRIAL
+
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
 
@@ -131,7 +131,7 @@ Dist::Zilla::Plugin::MetaNoIndex - Stop CPAN from indexing stuff
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 SYNOPSIS
 
@@ -199,11 +199,11 @@ Dist::Zilla roles: L<MetaProvider|Dist::Zilla::Role::MetaProvider>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
