@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::MetaYAML;
+package Dist::Zilla::Plugin::MetaYAML 6.013; # TRIAL
 # ABSTRACT: produce a META.yml
-$Dist::Zilla::Plugin::MetaYAML::VERSION = '6.004'; # TRIAL
+
 use Moose;
 with 'Dist::Zilla::Role::FileGatherer';
 
@@ -26,25 +26,6 @@ has filename => (
   default => 'META.yml',
 );
 
-#pod =attr version
-#pod
-#pod This parameter lets you pick what version of the spec to use when generating
-#pod the output.  It defaults to 1.4, the most commonly supported version at
-#pod present.
-#pod
-#pod B<This may change without notice in the future.>
-#pod
-#pod Once version 2 of the META file spec is more widely supported, this may default
-#pod to 2.
-#pod
-#pod =cut
-
-has version => (
-  is  => 'ro',
-  isa => 'Num',
-  default => '1.4',
-);
-
 sub gather_files {
   my ($self, $arg) = @_;
 
@@ -72,7 +53,10 @@ sub gather_files {
       }
 
       my $converter = CPAN::Meta::Converter->new($distmeta);
-      my $output    = $converter->convert(version => $self->version);
+      my $output    = $converter->convert(version => '1.4');
+      $output->{x_serialization_backend} = sprintf '%s version %s',
+            'YAML::Tiny', YAML::Tiny->VERSION;
+
       my $yaml = try {
         YAML::Tiny->new($output)->write_string; # text!
       }
@@ -117,7 +101,7 @@ Dist::Zilla::Plugin::MetaYAML - produce a META.yml
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 DESCRIPTION
 
@@ -132,17 +116,6 @@ For more information on this file, see L<Module::Build::API> and L<CPAN::Meta>.
 If given, parameter allows you to specify an alternate name for the generated
 file.  It defaults, of course, to F<META.yml>.
 
-=head2 version
-
-This parameter lets you pick what version of the spec to use when generating
-the output.  It defaults to 1.4, the most commonly supported version at
-present.
-
-B<This may change without notice in the future.>
-
-Once version 2 of the META file spec is more widely supported, this may default
-to 2.
-
 =head1 SEE ALSO
 
 Core Dist::Zilla plugins:
@@ -158,11 +131,11 @@ L<CPAN::Meta::Spec>, L<YAML>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
