@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::NextRelease;
+package Dist::Zilla::Plugin::NextRelease 6.013; # TRIAL
 # ABSTRACT: update the next release number in your changelog
-$Dist::Zilla::Plugin::NextRelease::VERSION = '6.004'; # TRIAL
+
 use namespace::autoclean;
 
 use Moose;
@@ -113,7 +113,7 @@ sub munge_files {
   my ($self) = @_;
 
   my ($file) = grep { $_->name eq $self->filename } @{ $self->zilla->files };
-  return unless $file;
+  $self->log_fatal([ 'failed to find %s in the distribution', $self->filename ]) if not $file;
 
   # save original unmunged content, for replacing back in the repo later
   my $content = $self->_original_changes_content($file->content);
@@ -281,7 +281,7 @@ Dist::Zilla::Plugin::NextRelease - update the next release number in your change
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 SYNOPSIS
 
@@ -409,11 +409,11 @@ L<TextTemplate|Dist::Zilla::Role::TextTemplate>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
