@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::PkgDist;
+package Dist::Zilla::Plugin::PkgDist 6.013; # TRIAL
 # ABSTRACT: add a $DIST to your packages
-$Dist::Zilla::Plugin::PkgDist::VERSION = '6.004'; # TRIAL
+
 use Moose;
 with(
   'Dist::Zilla::Role::FileMunger',
@@ -119,7 +119,7 @@ Dist::Zilla::Plugin::PkgDist - add a $DIST to your packages
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 DESCRIPTION
 
@@ -139,11 +139,11 @@ typically used when doing monkey patching or other tricky things.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
