@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::PkgVersion;
+package Dist::Zilla::Plugin::PkgVersion 6.013; # TRIAL
 # ABSTRACT: add a $VERSION to your packages
-$Dist::Zilla::Plugin::PkgVersion::VERSION = '6.004'; # TRIAL
+
 use Moose;
 with(
   'Dist::Zilla::Role::FileMunger',
@@ -332,7 +332,7 @@ Dist::Zilla::Plugin::PkgVersion - add a $VERSION to your packages
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 SYNOPSIS
 
@@ -434,11 +434,11 @@ numbers using C<our $VERSION = '...';> and without changing line numbers
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
