@@ -1,10 +1,11 @@
-package Dist::Zilla::Role::MintingProfile;
+package Dist::Zilla::Role::MintingProfile 6.013; # TRIAL
 # ABSTRACT: something that can find a minting profile dir
-$Dist::Zilla::Role::MintingProfile::VERSION = '6.004'; # TRIAL
+
 use Moose::Role;
 
 use namespace::autoclean;
 
+use Dist::Zilla::Path;
 use File::ShareDir;
 
 #pod =head1 DESCRIPTION
@@ -28,6 +29,11 @@ use File::ShareDir;
 
 requires 'profile_dir';
 
+around profile_dir => sub {
+  my ($orig, $self, @args) = @_;
+  path($self->$orig(@args));
+};
+
 1;
 
 __END__
@@ -42,7 +48,7 @@ Dist::Zilla::Role::MintingProfile - something that can find a minting profile di
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 DESCRIPTION
 
@@ -63,11 +69,11 @@ based on your profile with the:
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
