@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::ModuleMaker;
+package Dist::Zilla::Role::ModuleMaker 6.013; # TRIAL
 # ABSTRACT: something that injects module files into the dist
-$Dist::Zilla::Role::ModuleMaker::VERSION = '6.004'; # TRIAL
+
 use Moose::Role;
 with qw(
   Dist::Zilla::Role::Plugin
@@ -39,7 +39,7 @@ Dist::Zilla::Role::ModuleMaker - something that injects module files into the di
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 DESCRIPTION
 
@@ -55,11 +55,11 @@ file for the module being created.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
