@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::PrereqScanner;
+package Dist::Zilla::Role::PrereqScanner 6.013; # TRIAL
 # ABSTRACT: automatically extract prereqs from your modules
-$Dist::Zilla::Role::PrereqScanner::VERSION = '6.004'; # TRIAL
+
 use Moose::Role;
 with(
   'Dist::Zilla::Role::FileFinderUser' => {
@@ -186,7 +186,7 @@ Dist::Zilla::Role::PrereqScanner - automatically extract prereqs from your modul
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 ATTRIBUTES
 
@@ -230,11 +230,11 @@ The role was provided by Olivier Mengué (DOLMEN) and Philippe Bruhat (BOOK) at
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
