@@ -1,6 +1,6 @@
-package Dist::Zilla::Stash::User;
+package Dist::Zilla::Stash::User 6.013; # TRIAL
 # ABSTRACT: a stash of user name and email
-$Dist::Zilla::Stash::User::VERSION = '6.004'; # TRIAL
+
 use Moose;
 
 use namespace::autoclean;
@@ -38,15 +38,15 @@ Dist::Zilla::Stash::User - a stash of user name and email
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
