@@ -1,6 +1,6 @@
-package Dist::Zilla::Tester;
+package Dist::Zilla::Tester 6.013; # TRIAL
 # ABSTRACT: a testing-enabling stand-in for Dist::Zilla
-$Dist::Zilla::Tester::VERSION = '6.004'; # TRIAL
+
 use Moose;
 extends 'Dist::Zilla::Dist::Builder';
 
@@ -112,13 +112,13 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
 }
 
 {
-  package Dist::Zilla::Tester::_Builder;
-$Dist::Zilla::Tester::_Builder::VERSION = '6.004'; # TRIAL
-use Moose;
+  package Dist::Zilla::Tester::_Builder 6.013; # TRIAL
+
+  use Moose;
   extends 'Dist::Zilla::Dist::Builder';
   with 'Dist::Zilla::Tester::_Role';
 
-  use File::Copy::Recursive qw(dircopy);
+  use File::Copy::Recursive 0.41 qw(dircopy);
   use Dist::Zilla::Path;
 
   our $Log_Events = [];
@@ -250,13 +250,13 @@ use Moose;
 }
 
 {
-  package Dist::Zilla::Tester::_Minter;
-$Dist::Zilla::Tester::_Minter::VERSION = '6.004'; # TRIAL
-use Moose;
+  package Dist::Zilla::Tester::_Minter 6.013; # TRIAL
+
+  use Moose;
   extends 'Dist::Zilla::Dist::Minter';
   with 'Dist::Zilla::Tester::_Role';
 
-  use File::Copy::Recursive qw(dircopy);
+  use File::Copy::Recursive 0.41 qw(dircopy);
   use Dist::Zilla::Path;
 
   our $Log_Events = [];
@@ -355,15 +355,15 @@ Dist::Zilla::Tester - a testing-enabling stand-in for Dist::Zilla
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
