@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Dist::Zilla::Util;
+package Dist::Zilla::Util 6.013; # TRIAL
 # ABSTRACT: random snippets of code that Dist::Zilla wants
-$Dist::Zilla::Util::VERSION = '6.004'; # TRIAL
+
 use Carp ();
 use Encode ();
 
@@ -97,6 +97,7 @@ use String::RewritePrefix 0.006 rewrite => {
     ''  => 'Dist::Zilla::Plugin::',
   },
 };
+
 sub expand_config_package_name {
   shift; goto &_expand_config_package_name
 }
@@ -145,7 +146,7 @@ Dist::Zilla::Util - random snippets of code that Dist::Zilla wants
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 METHODS
 
@@ -186,11 +187,11 @@ otherwise, C<Dist::Zilla::Plugin::> is prepended
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
