@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Dist::Zilla::Util::AuthorDeps;
+package Dist::Zilla::Util::AuthorDeps 6.013; # TRIAL
 # ABSTRACT: Utils for listing your distribution's author dependencies
-$Dist::Zilla::Util::AuthorDeps::VERSION = '6.004'; # TRIAL
+
 use Dist::Zilla::Util;
 use Path::Tiny;
 use List::Util 1.45 ();
@@ -42,7 +42,12 @@ sub extract_author_deps {
   }
 
   for my $section ( sort keys %$config ) {
-    next if q[_] eq $section;
+    if (q[_] eq $section) {
+      my $version = $config->{_}{':version'};
+      $reqs->add_minimum('Dist::Zilla' => $version) if $version;
+      next;
+    }
+
     my $pack = $section;
     $pack =~ s{\s*/.*$}{}; # trim optional space and slash-delimited suffix
 
@@ -96,23 +101,33 @@ sub extract_author_deps {
   # for the common case (no inc::, no '; authordep') as in previous dzil
   # releases.
   @packages = ((sort grep /^inc::/, @packages), (grep !/^inc::/, @packages));
+  @packages = List::Util::uniq(@packages);
+
+  if ($missing) {
+    require Module::Runtime;
+
+    @packages =
+      grep {
+        $_ eq 'perl'
+        ? ! ($vermap->{perl} && eval "use $vermap->{perl}; 1")
+        : do {
+            my $m = $_;
+            ! eval {
+              # This will die if module is missing
+              Module::Runtime::require_module($m);
+              my $v = $vermap->{$m};
+              # This will die if VERSION is too low
+              !$v || $m->VERSION($v);
+              # Success!
+              1
+            }
+          }
+      } @packages;
+  }
 
   # Now that we have a sorted list of packages, use that to build an array of
   # hashrefs for display.
-  require Class::Load;
-
-  my @final =
-    map { { $_ => $vermap->{$_} } }
-    grep {
-      $missing
-        ? $_ eq 'perl'
-          ? ($vermap->{perl} ? !eval "use $vermap->{perl}; 1" : ())
-          : (! Class::Load::try_load_class($_, ($vermap->{$_} ? {-version => $vermap->{$_}} : ())))
-        : 1
-      }
-    List::Util::uniq(@packages);
-
-  return \@final;
+  [ map { { $_ => $vermap->{$_} } } @packages ]
 }
 
 1;
@@ -129,15 +144,15 @@ Dist::Zilla::Util::AuthorDeps - Utils for listing your distribution's author dep
 
 =head1 VERSION
 
-version 6.004
+version 6.013
 
 =head1 AUTHOR
 
-Ricardo SIGNES 🎃 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
